OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Tengiliðir",
    "Download" : "Niðurhal",
    "Copy link" : "Afrita tengil",
    "Click to copy the link to your clipboard" : "Smelltu til að afrita tengilinn á klippispjaldið",
    "Toggle sharing" : "Víxla deilingu af/á",
    "Delete" : "Eyða",
    "Rename" : "Endurnefna",
    "Share with users or groups" : "Deila með notendum eða hópum",
    "can edit" : "getur breytt",
    "Close" : "Loka",
    "Enabled" : "Virkt",
    "Disabled" : "Óvirkt",
    "Copied!" : "Afritað!",
    "Not supported!" : "Ekki stutt!",
    "Press ⌘-C to copy." : "Ýttu á ⌘-C til að afrita.",
    "Press Ctrl-C to copy." : "Ýttu á Ctrl-C til að afrita.",
    "Address book name" : "Heiti nafnaskrár",
    "Only these special characters are allowed: -_.!?#|()" : "Aðeins þessir sérstafir eru leyfðir: -_.!?#|()",
    "Address book could not be created." : "Tókst ekki að búa til nafnaskrá.",
    "The selected image is too big (max 1MB)" : "Valin mynd er of stór (hám. 1MB)",
    "This card is corrupted and has been fixed. Please check the data and trigger a save to make the changes permanent." : "Þetta nafnspjald er skemmt en viðgerð hefur farið fram. Farðu vel yfir upplýsingarnar og vistaðu það síðan til að gera breytingarnar varanlegar.",
    "No contacts in here" : "Engir tengiliðir hér",
    "Name" : "Nafn",
    "Organization" : "Stofnun/félag",
    "Title" : "Titill",
    "Add field …" : "Bæta við reit …",
    "Save changes" : "Vista breytingar",
    "Address book" : "Nafnaskrá",
    "Loading contacts …" : "Hleð inn tengiliðum …",
    "Import into" : "Flytja inn í",
    "Importing..." : "Innflutningur...",
    "Select your addressbook" : "Veldu nafnaskrá",
    "No search result for {query}" : "Engar leitarniðurstöður fyrir {query}",
    "All contacts" : "Allir tengiliðir",
    "Post office box" : "Pósthólf",
    "Postal code" : "Póstnúmer",
    "City" : "Borg",
    "State or province" : "Ríki eða fylki",
    "Country" : "Land",
    "Address" : "Slóð",
    "(new group)" : "(nýr hópur)",
    "Last name" : "Kenninafn",
    "First name" : "Eiginnafn",
    "Additional names" : "Aukanöfn",
    "Prefix" : "Forskeyti",
    "Suffix" : "Viðskeyti",
    "Importing into" : "Flyt inn í",
    "New contact" : "Nýr tengiliður",
    "Not grouped" : "Ekki hópað",
    "Sort by" : "Raða eftir",
    "{addressbook} shared by {owner}" : "{addressbook} deilt af {owner}",
    "Contact not found." : "Tengiliður fannst ekki.",
    "You don't have permission to write to this addressbook." : "Þú hefur ekki heimild til að skrifa í þessa nafnaskrá.",
    "Contact could not be created." : "Ekki var hægt að búa til tengilið.",
    "No contacts in file. Only vCard files are allowed." : "Engir tengiliðir í skrá. Einungis er tekið við vCard-skrám.",
    "Only vCard version 4.0 (RFC6350) or version 3.0 (RFC2426) are supported." : "Einungis vCard útgáfa 4.0 (RFC6350) eða útgáfa 3.0 (RFC2426) eru studdar.",
    "Contact could not be moved." : "Ekki var hægt að færa tengilið.",
    "Contact could not be saved." : "Ekki var hægt að vista tengilið.",
    "Waiting for the server to be ready…" : "Bíð eftir að þjónn sé tilbúinn…",
    "Importing…" : "Innflutningur…",
    "Display name" : "Birtingarnafn",
    "Nickname" : "Gælunafn",
    "Detailed name" : "Ítarlegt nafn",
    "Notes" : "Minnispunktar",
    "Website" : "Vefsvæði",
    "Federated Cloud ID" : "Skýjasambandsauðkenni (Federated Cloud ID)",
    "Home" : "Heima",
    "Work" : "Vinna",
    "Other" : "Annað",
    "Groups" : "Hópar",
    "Birthday" : "Afmælisdagur",
    "Anniversary" : "Afmæli",
    "Date of death" : "Dánardægur",
    "Email" : "Netfang",
    "Instant messaging" : "Snarskilaboð",
    "Phone" : "Sími",
    "Mobile" : "Farsími",
    "Work mobile" : "Vinna á ferðinni",
    "Fax" : "Fax",
    "Fax home" : "Heimafax",
    "Fax work" : "Vinnufax",
    "Pager" : "Símboði",
    "Voice" : "Raddskilaboð",
    "Car" : "Bíll",
    "Work pager" : "Vinnufriðþjófur",
    "Social network" : "Samfélagsnet",
    "Relationship" : "Vensl",
    "Spouse" : "Maki",
    "Child" : "Barn",
    "Mother" : "Móðir",
    "Father" : "Faðir",
    "Parent" : "Foreldri",
    "Brother" : "Bróðir",
    "Sister" : "Systir",
    "Relative" : "Ættingi",
    "Friend" : "Vinur",
    "Colleague" : "Samstarfsmaður",
    "Manager" : "Yfirmaður",
    "Assistant" : "Aðstoðarmaður",
    "Gender" : "Kyn",
    "Female" : "Kona",
    "Male" : "Karl",
    "Details" : "Nánar",
    "Settings" : "Stillingar"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
